tinymce.addI18n('tg',{
"Cut": "\u0411\u0443\u0440\u0438\u0434\u0430\u043d",
"Heading 5": "\u0421\u0430\u0440\u043b\u0430\u0432\u04b3\u0430\u0438 5",
"Header 2": "\u0421\u0430\u0440\u043b\u0430\u0432\u04b3\u0430\u0438 2",
"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X\/C\/V keyboard shortcuts instead.": "\u0411\u0430\u0440\u0438 \u0448\u0443\u0441\u0445\u0430\u0431\u0430\u0440\u0434\u043e\u0440\u0438 \u043a\u0430\u0440\u0434\u0430\u043d Ctrl+X\/C\/V \u0438\u0441\u0442\u0438\u0444\u043e\u0434\u0430 \u043a\u0443\u043d\u0435\u0434",
"Heading 4": "\u0421\u0430\u0440\u043b\u0430\u0432\u04b3\u0430\u0438 4",
"Div": "Div",
"Heading 2": "\u0421\u0430\u0440\u043b\u0430\u0432\u04b3\u0430\u0438 2",
"Paste": "\u0413\u0443\u0437\u043e\u0448\u0442\u0430\u043d",
"Close": "\u041c\u0430\u04b3\u043a\u0430\u043c \u043a\u0430\u0440\u0434\u0430\u043d",
"Font Family": "\u0428\u0440\u0438\u0444\u0442",
"Pre": "Pre",
"Align right": "\u0420\u043e\u0441\u0442 \u043a\u0430\u0440\u0434\u0430\u043d \u0430\u0437 \u0440\u043e\u0441\u0442",
"New document": "\u04b2\u0443\u04b7\u04b7\u0430\u0442\u0438 \u043d\u0430\u0432",
"Blockquote": "\u041d\u043e\u0445\u0443\u043d\u0430\u043a",
"Numbered list": "\u0420\u0443\u0439\u0445\u0430\u0442\u0438 \u0431\u043e \u0442\u0430\u0440\u0442\u0438\u0431",
"Heading 1": "\u0421\u0430\u0440\u043b\u0430\u0432\u04b3\u0430\u0438 1",
"Headings": "\u0421\u0430\u0440\u043b\u0430\u0432\u04b3\u0430\u04b3\u043e",
"Increase indent": "\u0410\u0431\u0437\u0430\u0441\u0442\u0440\u043e \u0432\u0430\u0441\u0435\u044a \u043a\u0430\u0440\u0434\u0430\u043d",
"Formats": "\u0424\u0430\u0440\u043c\u0430\u0442\u04b3\u043e",
"Headers": "\u0421\u0430\u0440\u043b\u0430\u0432\u04b3\u0430\u04b3\u043e",
"Select all": "\u0418\u043d\u0442\u0438\u0445\u043e\u0431\u0438 \u043a\u0443\u043b\u043b\u0438",
"Header 3": "\u0421\u0430\u0440\u043b\u0430\u0432\u04b3\u0430\u0438 3",
"Blocks": "\u0425\u0430\u0442\u0438 \u0431\u043b\u043e\u043a\u04e3",
"Undo": "\u0411\u043e\u0437 \u0433\u0430\u0440\u0434\u043e\u043d\u0438\u0434\u0430\u043d",
"Strikethrough": "\u0410\u0437 \u043c\u043e\u0431\u0430\u0439\u043d\u0430\u0448 \u0445\u0430\u0442 \u043a\u0430\u0448\u0438\u0434\u0430\u043d",
"Bullet list": "\u0420\u0443\u0439\u0445\u0430\u0442\u0438 \u0431\u0435 \u0442\u0430\u0440\u0442\u0438\u0431",
"Header 1": "\u0421\u0430\u0440\u043b\u0430\u0432\u04b3\u0430\u0438 1",
"Superscript": "\u0410\u0437 \u0445\u0430\u0442 \u0431\u043e\u043b\u043e\u0442\u0430\u0440",
"Clear formatting": "\u0424\u043e\u0440\u043c\u0430\u0442\u04b3\u043e\u0440\u043e \u0431\u0435\u043a\u043e\u0440 \u043a\u0430\u0440\u0434\u0430\u043d",
"Font Sizes": "\u04b2\u0430\u04b7\u043c\u0438 \u0448\u0440\u0438\u0444\u0442",
"Subscript": "\u0410\u0437 \u0445\u0430\u0442 \u043f\u043e\u0451\u043d\u0442\u0430\u0440",
"Header 6": "\u0421\u0430\u0440\u043b\u0430\u0432\u04b3\u0430\u0438 6",
"Redo": "\u0411\u0435\u043a\u043e\u0440 \u043a\u0430\u0440\u0434\u0430\u043d",
"Paragraph": "\u0410\u0431\u0437\u0430\u0441\u0442",
"Ok": "\u041e\u043a",
"Bold": "\u0492\u0430\u0444\u0441",
"Code": "Code",
"Italic": "\u0418\u0442\u0430\u043b\u0438\u043a",
"Align center": "\u0420\u043e\u0441\u0442 \u043a\u0430\u0440\u0434\u0430\u043d \u0430\u0437 \u043c\u043e\u0431\u0430\u0439\u043d",
"Header 5": "\u0421\u0430\u0440\u043b\u0430\u0432\u04b3\u0430\u0438 5",
"Heading 6": "\u0421\u0430\u0440\u043b\u0430\u0432\u04b3\u0430\u0438 6",
"Heading 3": "\u0421\u0430\u0440\u043b\u0430\u0432\u04b3\u0430\u0438 3",
"Decrease indent": "\u0410\u0431\u0437\u0430\u0441\u0442\u0440\u043e \u0445\u0443\u0440\u0434 \u043a\u0430\u0440\u0434\u0430\u043d",
"Header 4": "\u0421\u0430\u0440\u043b\u0430\u0432\u04b3\u0430\u0438 4",
"Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.": "\u0422\u043e \u043e\u043d \u0437\u0430\u043c\u043e\u043d\u0435, \u043a\u0438 \u0438\u043d \u0445\u043e\u043c\u0443\u0448 \u0430\u0441\u0442, \u04b3\u0430\u043c\u0447\u0443\u043d \u043c\u0430\u043d\u0442 \u0432\u043e\u0440\u0438\u0434 \u043a\u0443\u043d\u0435\u0434.",
"Underline": "\u0414\u0430\u0440 \u0442\u0430\u0433\u0430\u0448 \u0445\u0430\u0442 \u043a\u0430\u0448\u0438\u0434\u0430\u043d",
"Cancel": "\u0411\u0435\u043a\u043e\u0440 \u043a\u0430\u0440\u0434\u0430\u043d",
"Justify": "\u0410\u0437 \u04b3\u0430\u0440 \u0434\u0443 \u0442\u0430\u0440\u0430\u0444 \u0440\u043e\u0441\u0442 \u043a\u0430\u0440\u0434\u0430\u043d",
"Inline": "\u0414\u0430\u0440 \u044f\u043a \u0445\u0430\u0442",
"Copy": "\u041d\u0443\u0441\u0445\u0430\u0431\u043e\u0440\u0434\u043e\u043d\u0438 \u043a\u0430\u0440\u0434\u0430\u043d",
"Align left": "\u0420\u043e\u0441 \u043a\u0430\u0440\u0434\u0430\u043d \u0430\u0437 \u0447\u0430\u043f",
"Visual aids": "\u041a\u0443\u043c\u043c\u0430\u043a\u0438 \u0430\u0451\u043d\u04e3",
"Lower Greek": "\u0425\u0443\u0440\u0434\u0438 \u042e\u043d\u043e\u043d\u04e3",
"Square": "\u0427\u043e\u0440\u043a\u0443\u043d\u04b7\u0430",
"Default": "\u0411\u043e \u0442\u0430\u0440\u0437\u0438 \u0445\u043e\u043c\u0443\u0448\u04e3",
"Lower Alpha": "\u0425\u0443\u0440\u0434\u0438 \u044e\u043d\u043e\u043d\u04e3",
"Circle": "\u0414\u043e\u0438\u0440\u0430",
"Disc": "\u0414\u0438\u0441\u043a",
"Upper Alpha": "\u041a\u0430\u043b\u043e\u043d\u0438 \u044e\u043d\u043e\u043d\u04e3",
"Upper Roman": "\u041a\u0430\u043b\u043e\u043d\u0438 \u0440\u043e\u043c\u0430\u043d\u04e3",
"Lower Roman": "\u0425\u0443\u0440\u0434\u0438 \u0440\u043e\u043c\u0430\u043d\u04e3",
"Name": "\u041d\u043e\u043c",
"Anchor": "\u041b\u0430\u043d\u0433\u0430\u0440",
"You have unsaved changes are you sure you want to navigate away?": "\u0422\u0430\u0493\u0438\u0440\u043e\u0442\u04b3\u043e\u0438 \u043a\u0430\u0440\u0434\u0430\u0430\u0442\u043e\u043d\u0440\u043e \u0442\u043e \u04b3\u043e\u043b \u043d\u0438\u0433\u043e\u04b3 \u043d\u0430\u0434\u043e\u0448\u0442\u0430\u0435\u0434!\n\u041e\u0451 \u0448\u0443\u043c\u043e \u0434\u0430\u0440 \u04b3\u0430\u049b\u0438\u049b\u0430\u0442 \u043c\u0435\u0445\u043e\u04b3\u0435\u0434 \u043a\u0438 \u0431\u0430 \u0434\u0438\u0433\u0430\u0440 \u049b\u0438\u0441\u043c \u0433\u0443\u0437\u0430\u0440\u0435\u0434?",
"Restore last draft": "\u0422\u0430\u0493\u0438\u0440\u043e\u0442\u04b3\u043e\u0438 \u043e\u0445\u0438\u0440\u0438\u043d\u0440\u043e \u0431\u0435\u043a\u043e\u0440 \u043a\u0443\u043d",
"Special character": "\u0420\u0430\u043c\u0437\u04b3\u043e\u0438 \u043c\u0430\u0445\u0441\u0443\u0441",
"Source code": "\u041a\u043e\u0434\u0438 \u0430\u0441\u043b\u0438",
"B": "B",
"R": "R",
"G": "G",
"Color": "\u0420\u0430\u043d\u0433",
"Right to left": "\u0410\u0437 \u0440\u043e\u0441\u0442 \u0431\u0430 \u0447\u0430\u043f",
"Left to right": "\u0410\u0437 \u0447\u0430\u043f \u0431\u0430 \u0440\u043e\u0441\u0442",
"Emoticons": "\u042d\u04b3\u0441\u043e\u0441\u04b3\u043e",
"Robots": "Robots",
"Document properties": "\u04b2\u043e\u043b\u0430\u0442\u0438 \u04b3\u0443\u04b7\u04b7\u0430\u0442",
"Title": "\u0421\u0430\u0440\u043b\u0430\u0432\u04b3\u0430",
"Keywords": "\u041a\u0430\u043b\u0438\u043c\u0430\u04b3\u043e\u0438 \u043c\u0443\u0442\u0430\u043d\u043e\u0441\u0438\u0431",
"Encoding": "\u0411\u043e \u0440\u0430\u043c\u0437 \u0433\u0430\u0440\u0434\u043e\u043d\u0438\u0434\u0430\u043d",
"Description": "\u041c\u0430\u044a\u043b\u0443\u043c\u043e\u0442\u0438 \u043c\u0443\u0445\u0442\u0430\u0441\u0430\u0440",
"Author": "\u041c\u0443\u0430\u043b\u043b\u0438\u0444",
"Fullscreen": "\u041a\u0430\u043b\u043e\u043d \u043a\u0430\u0440\u0434\u0430\u043d",
"Horizontal line": "\u0425\u0430\u0442\u0438 \u0443\u0444\u0443\u049b\u04e3",
"Horizontal space": "\u0424\u043e\u0441\u0438\u043b\u0430\u0438 \u0443\u0444\u0443\u049b\u04e3",
"Insert\/edit image": "\u0412\u043e\u0440\u0438\u0434\/\u0422\u0430\u0493\u0438\u0440\u0438 \u0440\u0430\u0441\u043c",
"General": "\u041e\u0434\u0434\u0438",
"Advanced": "\u041c\u0443\u0442\u0430\u0440\u0430\u049b\u0438",
"Source": "\u041c\u0430\u043a\u043e\u043d\u0438 \u0430\u0441\u043e\u0441\u04e3",
"Border": "\u04b2\u0443\u0434\u0443\u0434",
"Constrain proportions": "\u0427\u0435\u043d\u0430\u043a\u04b3\u043e\u0438 \u043c\u0430\u04b7\u0431\u0443\u0440\u0438",
"Vertical space": "\u0424\u043e\u0441\u0438\u043b\u0430\u0438 \u0430\u043c\u0443\u0434\u04e3",
"Image description": "\u041c\u0430\u044a\u043b\u0443\u043c\u043e\u0442\u0438 \u043c\u0443\u0445\u0442\u0430\u0441\u0430\u0440",
"Style": "\u0421\u0442\u0438\u043b",
"Dimensions": "\u0427\u0435\u043d\u0430\u043a\u04b3\u043e",
"Insert image": "\u0420\u0430\u0441\u043c \u0432\u043e\u0440\u0438\u0434 \u043a\u0430\u0440\u0434\u0430\u043d",
"Zoom in": "Zoom in",
"Contrast": "Contrast",
"Back": "Back",
"Gamma": "Gamma",
"Flip horizontally": "Flip horizontally",
"Resize": "Resize",
"Sharpen": "Sharpen",
"Zoom out": "Zoom out",
"Image options": "Image options",
"Apply": "Apply",
"Brightness": "Brightness",
"Rotate clockwise": "Rotate clockwise",
"Rotate counterclockwise": "Rotate counterclockwise",
"Edit image": "Edit image",
"Color levels": "Color levels",
"Crop": "Crop",
"Orientation": "Orientation",
"Flip vertically": "Flip vertically",
"Invert": "Invert",
"Insert date\/time": "\u0412\u043e\u0440\u0438\u0434\u0438 \u0420\u04ef\u0437\/\u0421\u043e\u0430\u0442",
"Remove link": "\u041d\u0435\u0441\u0442 \u043a\u0430\u0440\u0434\u0430\u043d\u0438 \u0438\u0441\u0442\u0438\u043d\u043e\u0434",
"Url": "Url",
"Text to display": "\u041c\u0430\u0442\u043d \u0431\u0430\u0440\u043e\u0438 \u043c\u0430\u043d\u0437\u0443\u0440",
"Anchors": "\u041b\u0430\u043d\u0433\u0430\u0440",
"Insert link": "\u0418\u0441\u0442\u0438\u043d\u043e\u0434 \u0433\u0443\u0437\u043e\u0448\u0442\u0430\u043d",
"New window": "\u0422\u0438\u0440\u0435\u0437\u0430\u0438 \u043d\u0430\u0432",
"None": "\u04b2\u0435\u04b7 \u0447\u0438\u0437",
"The URL you entered seems to be an external link. Do you want to add the required http:\/\/ prefix?": "URL \u0430\u0434\u0440\u0435\u0441\u0435, \u043a\u0438 \u0448\u0443\u043c\u043e \u0432\u043e\u0440\u0438\u0434 \u043a\u0430\u0440\u0434\u0435\u0434 \u0438\u0441\u0442\u0438\u043d\u043e\u0434 \u0430\u0441\u0442. \u041f\u0440\u0435\u0444\u0438\u043a\u0441\u0438 http:\/\/: \u0438\u043b\u043e\u0432\u0430 \u043a\u0443\u043d\u0430\u043c?",
"Target": "\u041d\u0438\u0448\u043e\u043d\u0430",
"The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?": "URL \u0430\u0434\u0440\u0435\u0441\u0435, \u043a\u0438 \u0448\u0443\u043c\u043e \u0432\u043e\u0440\u0438\u0434 \u043a\u0430\u0440\u0434\u0435\u0434 Email \u0430\u0434\u0440\u0435\u0441 \u0430\u0441\u0442. G\u0440\u0435\u0444\u0438\u043a\u0441\u0438 mailto: \u0438\u043b\u043e\u0432\u0430 \u043a\u0443\u043d\u0430\u043c?",
"Insert\/edit link": "\u0412\u043e\u0440\u0438\u0434\/\u0442\u0430\u0493\u0438\u0440 \u0434\u043e\u0434\u0430\u043d\u0438 \u0438\u0441\u0442\u0438\u043d\u043e\u0434",
"Insert\/edit video": "\u0412\u043e\u0440\u0438\u0434\/\u0442\u0430\u0493\u0438\u0440\u0438 \u0432\u0438\u0434\u0435\u043e",
"Poster": "\u042d\u044a\u043b\u043e\u043d\u043d\u043e\u043c\u0430",
"Alternative source": "\u0421\u0430\u0440\u0447\u0430\u0448\u043c\u0430\u0438 \u0430\u043b\u0442\u0435\u0440\u043d\u0430\u0442\u0438\u0432\u04e3",
"Paste your embed code below:": "embed \u043a\u043e\u0434\u0440\u043e \u0438\u043d\u04b7\u043e \u0432\u043e\u0440\u0438\u0434 \u043a\u0443\u043d\u0435\u0434",
"Insert video": "\u0412\u043e\u0440\u0438\u0434\u0438 \u0432\u0438\u0434\u0435\u043e",
"Embed": "Embed",
"Nonbreaking space": "\u0411\u0435\u0444\u043e\u0441\u0438\u043b\u0430",
"Page break": "\u0421\u0430\u04b3\u0438\u0444\u0430\u0440\u043e \u0448\u0438\u043a\u0430\u0441\u0442\u0430\u043d",
"Paste as text": "\u0413\u0443\u0437\u043e\u0448\u0442\u0430\u043d \u04b3\u0430\u043c\u0447\u0443 \u043c\u0430\u0442\u043d",
"Preview": "\u041c\u0430\u043d\u0437\u0443\u0440",
"Print": "\u0427\u043e\u043f \u043a\u0430\u0440\u0434\u0430\u043d",
"Save": "\u041d\u0438\u0433\u043e\u04b3 \u0434\u043e\u0448\u0442\u0430\u043d",
"Could not find the specified string.": "\u0425\u0430\u0442\u0438 \u0434\u0430\u0440\u0445\u043e\u0441\u0442\u0448\u0443\u0434\u0430\u0440\u043e \u0451\u0444\u0442\u0430 \u043d\u0430\u0442\u0430\u0432\u043e\u043d\u0438\u0441\u0442\u0430\u043c",
"Replace": "\u0422\u0430\u0493\u0438\u0440",
"Next": "\u041e\u044f\u043d\u0434\u0430",
"Whole words": "\u041a\u0430\u043b\u0438\u043c\u0430\u04b3\u043e\u0438 \u043f\u0443\u0440\u0440\u0430",
"Find and replace": "\u0401\u0444\u0442\u0430\u043d \u0432\u0430 \u0442\u0430\u0493\u0438\u0440 \u0434\u043e\u0434\u0430\u043d",
"Replace with": "\u0422\u0430\u0493\u0438\u0440 \u0431\u0430",
"Find": "\u0401\u0444\u0442\u0430\u043d",
"Replace all": "\u0422\u0430\u0493\u0438\u0440\u0438 \u04b3\u0430\u043c\u0430\u0430\u0448",
"Match case": "\u041c\u0443\u0432\u043e\u0444\u0438\u049b\u0430\u0442",
"Prev": "\u0413\u0443\u0437\u0430\u0448\u0442\u0430",
"Spellcheck": "\u0422\u0430\u0444\u0442\u0438\u0448\u0438 \u0433\u0440\u0430\u043c\u043c\u0430\u0442\u0438\u043a\u04e3",
"Finish": "\u0422\u0430\u043c\u043e\u043c",
"Ignore all": "\u0410\u04b3\u0430\u043c\u0438\u044f\u0442 \u043d\u0430\u0434\u043e\u0434\u0430\u043d \u0431\u0430 \u04b3\u0430\u043c\u043c\u0430\u0448",
"Ignore": "\u0410\u04b3\u0430\u043c\u0438\u044f\u0442 \u043d\u0430\u0434\u043e\u0434\u0430\u043d",
"Add to Dictionary": "\u0414\u0430\u0440 \u043b\u0443\u0493\u0430\u0442 \u0438\u043b\u043e\u0432\u0430 \u043a\u0443\u043d",
"Insert row before": "\u0425\u0430\u0442 \u0432\u043e\u0440\u0438\u0434 \u043a\u0430\u0440\u0434\u0430\u043d \u043f\u0435\u0448 \u0430\u0437",
"Rows": "\u0425\u0430\u0442\u04b3\u043e",
"Height": "\u0411\u0430\u043b\u0430\u043d\u0434\u0438",
"Paste row after": "\u0425\u0430\u0442 \u0433\u0443\u0437\u043e\u0448\u0442\u0430\u043d \u043f\u0430\u0441 \u0430\u0437",
"Alignment": "\u0420\u043e\u0441\u0442 \u043a\u0430\u0440\u0434\u0430\u043d",
"Border color": "\u0420\u0430\u043d\u0433\u0438 \u04b3\u0443\u0434\u0443\u0434",
"Column group": "\u0413\u0443\u0440\u0443\u04b3\u0438 \u0441\u0443\u0442\u0443\u043d",
"Row": "\u0425\u0430\u0442",
"Insert column before": "\u0421\u0443\u0442\u0443\u043d \u0432\u043e\u0440\u0438\u0434 \u043a\u0430\u0440\u0434\u0430\u043d \u043f\u0435\u0448 \u0430\u0437",
"Split cell": "\u0421\u04ef\u0440\u043e\u0445\u0438\u04b3\u043e\u0440\u043e \u0431\u0443\u0440\u0438\u0434\u0430\u043d",
"Cell padding": "\u0424\u043e\u0441\u0438\u043b\u0430\u0438 \u0434\u0430\u0440\u0443\u043d\u0430",
"Cell spacing": "\u0424\u043e\u0441\u0438\u043b\u0430\u0438 \u0431\u0435\u0440\u0443\u043d\u0430",
"Row type": "\u041d\u0430\u043c\u0443\u0434\u0438 \u0445\u0430\u0442",
"Insert table": "\u0412\u043e\u0440\u0438\u0434 \u043a\u0430\u0440\u0434\u0430\u043d\u0438 \u04b7\u0430\u0434\u0432\u0430\u043b",
"Body": "\u049a\u0438\u0441\u043c\u0438 \u0430\u0441\u043b\u0438",
"Caption": "\u0421\u0430\u0440\u043b\u0430\u0432\u04b3\u0430",
"Footer": "\u049a\u0438\u0441\u043c\u0438 \u043f\u043e\u0451\u043d\u0438",
"Delete row": "\u041d\u0435\u0441\u0442 \u043a\u0430\u0440\u0434\u0430\u043d\u0438 \u0445\u0430\u0442",
"Paste row before": "\u0425\u0430\u0442 \u0433\u0443\u0437\u043e\u0448\u0442\u0430\u043d \u043f\u0435\u0448 \u0430\u0437",
"Scope": "Scope",
"Delete table": "\u041d\u0435\u0441\u0442 \u043a\u0430\u0440\u0434\u0430\u043d\u0438 \u04b7\u0430\u0434\u0432\u0430\u043b",
"H Align": "\u0410\u0437 \u0431\u043e\u043b\u043e \u0431\u0430 \u043f\u043e\u0451\u043d",
"Top": "\u0411\u043e\u043b\u043e",
"Header cell": "\u0421\u0430\u0440\u043b\u0430\u0432\u04b3\u0430",
"Column": "\u0421\u0443\u0442\u0443\u043d",
"Row group": "\u0413\u0443\u0440\u0443\u04b3\u0438 \u0445\u0430\u0442\u04b3\u043e",
"Cell": "\u0421\u04ef\u0440\u043e\u0445",
"Middle": "\u041c\u043e\u0431\u0430\u0439\u043d",
"Cell type": "\u041d\u0430\u043c\u0443\u0434\u0438 \u0441\u0443\u0440\u043e\u0445\u04e3",
"Copy row": "\u041d\u0443\u0441\u0445\u0430\u0431\u043e\u0440\u0434\u043e\u0440\u0438\u0438 \u0445\u0430\u0442",
"Row properties": "\u0425\u0443\u0441\u0443\u0441\u0438\u044f\u0442\u0438 \u0445\u0430\u0442",
"Table properties": "\u0425\u0443\u0441\u0443\u0441\u0438\u044f\u0442\u0438 \u04b7\u0430\u0434\u0432\u0430\u043b",
"Bottom": "\u041f\u043e\u0451\u043d",
"V Align": "\u0410\u0437 \u0447\u0430\u043f \u0431\u0430 \u0440\u043e\u0441\u0442",
"Header": "\u049a\u0438\u0441\u043c\u0438 \u0431\u043e\u043b\u043e\u0438",
"Right": "\u0420\u043e\u0441\u0442",
"Insert column after": "\u0421\u0443\u0442\u0443\u043d \u0432\u043e\u0440\u0438\u0434 \u043a\u0430\u0440\u0434\u0430\u043d \u043f\u0430\u0441 \u0430\u0437",
"Cols": "\u0421\u0443\u0442\u0443\u043d\u04b3\u043e",
"Insert row after": "\u0425\u0430\u0442 \u0432\u043e\u0440\u0438\u0434 \u043a\u0430\u0440\u0434\u0430\u043d \u043f\u0430\u0441 \u0430\u0437",
"Width": "\u041f\u0430\u04b3\u043d\u0438",
"Cell properties": "\u0425\u0443\u0441\u0443\u0441\u0438\u044f\u0442\u0438 \u0441\u04ef\u0440\u043e\u0445",
"Left": "\u0427\u0430\u043f",
"Cut row": "\u0411\u0443\u0440\u0438\u0434\u0430\u043d\u0438 \u0445\u0430\u0442",
"Delete column": "\u041d\u0435\u0441\u0442 \u043a\u0430\u0440\u0434\u0430\u043d\u0438 \u0441\u0443\u0442\u0443\u043d",
"Center": "\u041c\u0430\u0440\u043a\u0430\u0437",
"Merge cells": "\u0421\u04ef\u0440\u043e\u0445\u0438\u04b3\u043e\u0440\u043e \u044f\u043a\u04b7\u043e\u044f \u043a\u0430\u0440\u0434\u0430\u043d",
"Insert template": "\u0412\u043e\u0440\u0438\u0434\u0438 \u049b\u043e\u043b\u0430\u0431",
"Templates": "\u049a\u043e\u043b\u0430\u0431",
"Background color": "\u0420\u0430\u043d\u0433\u0438 \u043f\u0443\u0448\u0442\u0438 \u043c\u0430\u0442\u043d",
"Custom...": "\u0425\u0443\u0441\u0443\u0441\u04e3",
"Custom color": "\u0420\u0430\u043d\u0433\u0438 \u0445\u0443\u0441\u0443\u0441\u04e3",
"No color": "\u0411\u0435 \u0440\u0430\u043d\u0433",
"Text color": "\u0420\u0430\u043d\u0433\u0438 \u043c\u0430\u0442\u043d",
"Show blocks": "\u041d\u0438\u0448\u043e\u043d \u0434\u043e\u0434\u0430\u043d\u0438 \u0433\u0443\u0440\u0443\u04b3\u04b3\u043e",
"Show invisible characters": "\u0420\u0430\u043c\u0437\u04b3\u043e\u0438 \u043c\u0430\u0445\u0441\u0443\u0441\u0440\u043e \u043d\u0438\u0448\u043e\u043d \u0434\u043e\u0434\u0430\u043d",
"Words: {0}": "\u041a\u043b\u0438\u043c\u0430\u04b3\u043e: {0}",
"Insert": "\u0412\u043e\u0440\u0438\u0434",
"File": "\u0424\u0430\u0439\u043b",
"Edit": "\u0422\u0430\u0493\u0438\u0440\u043e\u0442",
"Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help": "\u041c\u0435\u043d\u044e ALT-F9. \u0410\u0441\u0431\u043e\u0431\u04b3\u043e ALT-F10. \u041a\u0443\u043c\u043c\u0430\u043a ALT-0",
"Tools": "\u0410\u0441\u0431\u043e\u0431\u04b3\u043e",
"View": "\u041c\u0430\u043d\u0437\u0443\u0440 \u043a\u0430\u0440\u0434\u0430\u043d",
"Table": "\u04b6\u0430\u0434\u0432\u0430\u043b",
"Format": "\u0424\u043e\u0440\u043c\u0430\u0442"
});